@@ -8,7 +8,6 @@ from mlagents.trainers.settings import RunOptions, TrainerSettings
 from TransformsAI.Animo.Data import AgentData, LevelData
 from TransformsAI.Animo.Data import AgentCheckpointAccumulator, Serializer
 
-
 INPUT_FOLDER_NAME = "Input"
 OUTPUT_FOLDER_NAME = "Output"
 AGENTS_FOLDER_NAME = "Agents"
@@ -19,6 +18,7 @@ AGENT_CHECKPOINT_FILE_NAME = "checkpoint.pt"
 
 BehaviorName = str
 
+
 class AnimoTrainingSession:
     def __init__(self, folder_path: str, daemon_pid: Optional[int] = None) -> None:
         self.id: str
@@ -35,7 +35,7 @@ class AnimoTrainingSession:
         else:
             self.should_check_daemon = False
 
-        ## Input folders
+        # Input folders
         training_session_full_folder_path = pathlib.Path(folder_path)
         if not os.path.isdir(training_session_full_folder_path):
             raise ValueError("Training session folder not found")
@@ -57,11 +57,12 @@ class AnimoTrainingSession:
         self.run_options = RunOptions.from_argparse(args)
 
         if self.run_options.env_settings.seed == -1:
-            self.run_options.env_settings.seed = np.random.randint(0, 10000) #type:ignore
+            self.run_options.env_settings.seed = np.random.randint(0, 10000)  # type:ignore
 
         self.id = training_session_full_folder_path.name
         self.run_options.checkpoint_settings.run_id = self.id
-        self.run_options.checkpoint_settings.results_dir = str(os.path.join(training_session_full_folder_path, OUTPUT_FOLDER_NAME, AGENTS_FOLDER_NAME))
+        self.run_options.checkpoint_settings.results_dir = str(
+            os.path.join(training_session_full_folder_path, OUTPUT_FOLDER_NAME, AGENTS_FOLDER_NAME))
 
         # Level
         input_level_full_path = os.path.join(input_folder_full_path, LEVEL_FILE_NAME)
@@ -101,15 +102,16 @@ class AnimoTrainingSession:
 
             agent_checkpoint_full_path = os.path.join(agent_full_path, AGENT_CHECKPOINT_FILE_NAME)
             if os.path.isfile(agent_checkpoint_full_path):
-                trainer_settings: TrainerSettings = self.run_options.behaviors.get(character_id) #type: ignore
+                trainer_settings: TrainerSettings = self.run_options.behaviors.get(character_id)  # type: ignore
                 trainer_settings.init_path = agent_checkpoint_full_path
 
-            self.agent_output_paths[character_id] = os.path.join(training_session_full_folder_path, OUTPUT_FOLDER_NAME, AGENTS_FOLDER_NAME, character_id)
+            self.agent_output_paths[character_id] = os.path.join(training_session_full_folder_path, OUTPUT_FOLDER_NAME,
+                                                                 AGENTS_FOLDER_NAME, character_id)
 
-        #Output folders and files
+        # Output folders and files
         output_folder_full_path = os.path.join(training_session_full_folder_path, OUTPUT_FOLDER_NAME)
         if os.path.isdir(output_folder_full_path):
-            timestamp = int(time.time_ns()/1000)
+            timestamp = int(time.time_ns() / 1000)
             new_folder_name = OUTPUT_FOLDER_NAME + "_" + str(timestamp)
             new_folder_full_path = os.path.join(training_session_full_folder_path, new_folder_name)
             print(f"Found existing output folder. Renaming it to {new_folder_name}")
@@ -123,4 +125,3 @@ class AnimoTrainingSession:
 
         output_level_full_path = os.path.join(output_folder_full_path, LEVEL_FILE_NAME)
         shutil.copy(input_level_full_path, output_level_full_path)
-
