@@ -25,6 +25,7 @@ parser.add_argument(
     action='version', version=f"%(prog)s {__version__}"
 )
 
+
 def main():
     parsed_args = parser.parse_args()
     print(ASCII_LOGO)
@@ -58,7 +59,7 @@ def main():
                 config_str = file.read()
             config_path = str(Path("./llm_mono_config").resolve())
 
-            config_str = config_str.replace("$mono_libdir", lib_path )
+            config_str = config_str.replace("$mono_libdir", lib_path)
 
             with open(config_path, mode='w', encoding='utf-8') as file:
                 file.write(config_str)
@@ -66,25 +67,38 @@ def main():
             os.environ["MONO_CONFIG"] = config_path
 
         import clr_loader
-        runtime = clr_loader.get_mono(libmono=libmono,debug=False) #type: ignore
+        runtime = clr_loader.get_mono(libmono=libmono, debug=False)  # type: ignore
 
-    from pythonnet import load
+    import pythonnet
 
-    load(runtime)
+    pythonnet.load(runtime)
     import clr, pathlib
 
-    CURRENT_DIR = pathlib.Path(__file__).parent.resolve()
-    ANIMO_UNITY_DLL_DIR = os.path.realpath(os.path.join(CURRENT_DIR, "lib"))
+    def load_dll(base_path: str, override_path: str, dll_name: str):
+        base_dll = os.path.join(base_path, dll_name)
 
+        if not override_path:
+            clr.AddReference(base_dll)
+        else:
+            override_dll = os.path.join(override_path, dll_name)
+
+            if os.path.isfile(override_dll):
+                clr.AddReference(override_dll)
+            elif os.path.isfile(base_dll):
+                clr.AddReference(base_dll)
+            else:
+                raise ValueError(f"Missing important dll: {dll_name}")
+
+    current_dir = pathlib.Path(__file__).parent.resolve()
+    animo_unity_dll_dir = os.path.realpath(os.path.join(current_dir, "lib"))
+
+    os.environ["PATH"] += os.pathsep + animo_unity_dll_dir
     dll_dir_override = os.getenv("ANIMO_DLL_DIRECTORY")
-    if dll_dir_override:
-        ANIMO_UNITY_DLL_DIR = dll_dir_override
 
-    # Load Animo DLLs
-    for f in os.listdir(ANIMO_UNITY_DLL_DIR):
-        dll_path = os.path.join(ANIMO_UNITY_DLL_DIR, f)
-        if os.path.isfile(dll_path) and dll_path.endswith(".dll"):
-            clr.AddReference(dll_path)
+    load_dll(animo_unity_dll_dir, dll_dir_override, "System.Numerics.Vectors.dll")
+    load_dll(animo_unity_dll_dir, dll_dir_override, "Newtonsoft.Json.dll")
+    load_dll(animo_unity_dll_dir, dll_dir_override, "AnimoSimulation.dll")
+    load_dll(animo_unity_dll_dir, dll_dir_override, "AnimoData.dll")
 
     from animo_trainer.animo_training_session import AnimoTrainingSession
     from animo_trainer.animo_trainer_controller import AnimoTrainingController
@@ -103,6 +117,10 @@ def main():
     animo_trainer_controller = AnimoTrainingController(training_session_data)
     print(f"Animo-Learn::Started")
     animo_trainer_controller.train()
+    try:
+        pythonnet.unload()
+    except Exception as e:
+        print(e)
     print(f"Animo-Learn::Stopped")
 
 
